<?php

/*
 * 2007-2014 PrestaShop
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Open Software License (OSL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/osl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to http://www.prestashop.com for more information.
 *
 *  @author PrestaShop SA <contact@prestashop.com>
 *  @copyright  2007-2014 PrestaShop SA
 *  @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
 *  International Registered Trademark & Property of PrestaShop SA
 */

include_once 'TntConnect.php';

class TntAccount extends ObjectModel {

    public $id_tnt_account;
    public $name;
    public $loginuser;
    public $password;
    public $account;
    public $envio_email_cliente;
    public $width;
    public $height;
    public $depth;
    public $weight;
    public $prefered_time_in;
    public $prefered_time_out;
    public $company_name;
    public $company_address_1;
    public $company_address_2;
    public $company_address_3;
    public $company_city;
    public $id_state;
    public $company_postcode;
    public $id_country;
    public $company_vat;
    public $company_contact_name;
    public $company_contact_dial_code;
    public $company_contact_telephone;
    public $company_contact_email;

    /** @var bool active state */
    public $active;
    public $principal;
    public $id_tnt_service;
    public $id_tnt_service_default;

    /**
     * @see ObjectModel::$definition
     */
    public static $definition = array(
        'table' => 'tnt_account',
        'primary' => 'id_tnt_account',
        'fields' => array(
            'name' => array('type' => self::TYPE_STRING, 'validate' => 'isGenericName', 'required' => true, 'size' => 64),
            'loginuser' => array('type' => self::TYPE_STRING, 'validate' => 'isGenericName', 'required' => true, 'size' => 64),
            'password' => array('type' => self::TYPE_STRING, 'validate' => 'isPasswd', 'required' => true, 'size' => 64),
            'account' => array('type' => self::TYPE_STRING, 'validate' => 'isGenericName', 'required' => true, 'size' => 64),
            'envio_email_cliente' => array('type' => self::TYPE_BOOL, 'validate' => 'isBool', 'required' => true, 'size' => 1),
            'width' => array('type' => self::TYPE_FLOAT, 'validate' => 'isGenericName', 'required' => true, 'size' => 5),
            'height' => array('type' => self::TYPE_FLOAT, 'validate' => 'isGenericName', 'required' => true, 'size' => 5),
            'depth' => array('type' => self::TYPE_FLOAT, 'validate' => 'isGenericName', 'required' => true, 'size' => 5),
            'weight' => array('type' => self::TYPE_FLOAT, 'validate' => 'isGenericName', 'required' => true, 'size' => 5),
            'prefered_time_in' => array('type' => self::TYPE_DATE, 'validate' => 'isGenericName', 'required' => true),
            'prefered_time_out' => array('type' => self::TYPE_DATE, 'validate' => 'isGenericName', 'required' => true),
            'active' => array('type' => self::TYPE_BOOL, 'validate' => 'isBool'),
            'principal' => array('type' => self::TYPE_BOOL, 'validate' => 'isBool'),
            'id_tnt_service' => array('type' => self::TYPE_STRING, 'size' => 255, 'required' => true),
            'id_tnt_service_default' => array('type' => self::TYPE_STRING, 'size' => 255, 'required' => true),
            'company_name' => array('type' => self::TYPE_STRING, 'validate' => 'isGenericName', 'required' => true, 'size' => 255),
            'company_address_1' => array('type' => self::TYPE_STRING, 'validate' => 'isAddress', 'required' => true, 'size' => 30),
            'company_address_2' => array('type' => self::TYPE_STRING, 'validate' => 'isAddress', 'required' => false, 'size' => 30),
            'company_address_3' => array('type' => self::TYPE_STRING, 'validate' => 'isAddress', 'required' => false, 'size' => 30),
            'company_city' => array('type' => self::TYPE_STRING, 'validate' => 'isCityName', 'required' => true, 'size' => 255),
            'id_state' => array('type' => self::TYPE_INT, 'validate' => 'isGenericName', 'required' => true, 'size' => 10),
            'company_postcode' => array('type' => self::TYPE_STRING, 'validate' => 'isPostCode', 'required' => true, 'size' => 8),
            'id_country' => array('type' => self::TYPE_INT, 'validate' => 'isGenericName', 'required' => true, 'size' => 10),
            'company_vat' => array('type' => self::TYPE_STRING, 'validate' => 'isGenericName', 'required' => false, 'size' => 11),
            'company_contact_name' => array('type' => self::TYPE_STRING, 'validate' => 'isGenericName', 'required' => true, 'size' => 255),
            'company_contact_dial_code' => array('type' => self::TYPE_STRING, 'validate' => 'isGenericName', 'required' => true, 'size' => 7),
            'company_contact_telephone' => array('type' => self::TYPE_STRING, 'validate' => 'isPhoneNumber', 'required' => true, 'size' => 9),
            'company_contact_email' => array('type' => self::TYPE_STRING, 'validate' => 'isEmail', 'required' => true, 'size' => 255),
        ),
    );

    public static function getTntAccount() {

        $tntaccounts = array();
        $result = Db::getInstance(_PS_USE_SQL_SLAVE_)->ExecuteS('
		SELECT ta.*
		FROM `' . _DB_PREFIX_ . 'tnt_account` ta 
		WHERE ta.active = 1
		ORDER BY ta.principal desc,ta.name ASC');

        foreach ($result as $row)
            $tntaccounts[$row['id_tnt_account']] = $row;

        return $tntaccounts;
    }

    public static function getTntAccountById($id) {

        $tntaccounts = array();
        $result = Db::getInstance(_PS_USE_SQL_SLAVE_)->ExecuteS('
		SELECT ta.* , ctr.iso_code as company_country, sta.name as company_province
		FROM `' . _DB_PREFIX_ . 'tnt_account` ta 
                left join `' . _DB_PREFIX_ . 'country` ctr on ctr.id_country = ta.id_country
                left join `' . _DB_PREFIX_ . 'state` sta on sta.id_country = ctr.id_country and sta.id_state = ta.id_state
		WHERE ta.active = 1 and ta.id_tnt_account = ' . $id . '
		ORDER BY ta.name ASC');

        foreach ($result as $row)
            $tntaccounts[$row['id_tnt_account']] = $row;

        return $tntaccounts;
    }

    public static function getTntAccountForLabelForm() {

        $tntaccounts = array();
        $result = Db::getInstance(_PS_USE_SQL_SLAVE_)->ExecuteS('
		SELECT ta.id_tnt_account as value,
                       ta.name as name, ta.id_tnt_service,ta.id_tnt_service_default
		FROM `' . _DB_PREFIX_ . 'tnt_account` ta 
		WHERE ta.active = 1
		ORDER BY ta.principal desc, ta.name ASC');

        foreach ($result as $row)
            $tntaccounts[$row['value']] = $row;

        return $tntaccounts;
    }

    public static function getDefaultValues($id_tnt_account = null) {
        if ($id_tnt_account) {
            $query = "select * from `" . _DB_PREFIX_ . "tnt_account` where id_tnt_account = '" . $id_tnt_account . "'";
        } else {
            $query = "select * from `" . _DB_PREFIX_ . "tnt_account` ";
        }
        $result = Db::getInstance(_PS_USE_SQL_SLAVE_)->ExecuteS($query);


        if (!$result) {
            return false;
        }
        return $result[0];
    }

    public static function processCambiaPrincipal($id_tnt_account) {
        $data = array(
            'principal' => 0,
        );
        Db::getInstance(_PS_USE_SQL_SLAVE_)->update('tnt_account', $data, "id_tnt_account <> '" . $id_tnt_account . "'");
        $data = array(
            'principal' => 1,
        );
        return Db::getInstance(_PS_USE_SQL_SLAVE_)->update('tnt_account', $data, "id_tnt_account = '" . $id_tnt_account . "'");
    }

    public function update($null_values = false) {
        
        if (is_array($this->id_tnt_service)) {
            $this->id_tnt_service = implode(',', $this->id_tnt_service);
        }
        
        $return = parent::update($null_values);
        if($this->principal == '1'){
            TntAccount::processCambiaPrincipal($this->id_tnt_account);
        }
        return $return;
    }

}
