<?php

/*
 * 2007-2014 PrestaShop
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Open Software License (OSL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/osl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to http://www.prestashop.com for more information.
 *
 *  @author PrestaShop SA <contact@prestashop.com>
 *  @copyright  2007-2014 PrestaShop SA
 *  @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
 *  International Registered Trademark & Property of PrestaShop SA
 */

include_once 'TntConnect.php';

class TntOrder extends ObjectModel {

    public $name;
    public $loginuser;
    public $password;
    public $account;

    /** @var bool active state */
    public $active;

    /**
     * @see ObjectModel::$definition
     */
    public static $definition = array(
        'table' => 'orders',
        'primary' => 'id_order',
        'fields' => array(
            'reference' => array('type' => self::TYPE_STRING, 'validate' => 'isGenericName', 'required' => true, 'size' => 64),
        ),
    );

    public function getOrder($lang, $order_by = null, $reference = null, $status = null, $manifested = null, $connumber = null, $booked = null, $manifest_date_ini = null, $manifest_date_end = null, $client = null) {
        if ($manifest_date_ini) {
            $day = substr($manifest_date_ini, 0, 2);
            $month = substr($manifest_date_ini, 3, 2);
            $year = substr($manifest_date_ini, -4);
            $manifest_date_ini = $year . '-' . $month . '-' . $day;
        }
        if ($manifest_date_end) {
            $day = substr($manifest_date_end, 0, 2);
            $month = substr($manifest_date_end, 3, 2);
            $year = substr($manifest_date_end, -4);
            $manifest_date_end = $year . '-' . $month . '-' . $day;
        }

        $query = "
		SELECT orde.id_order, orde.reference, osl.name, tnt_lab.manifested, tnt_lab.booked, tnt_lab.connumber, os.color, cust.firstname, cust.lastname, cust.email
		FROM `" . _DB_PREFIX_ . "orders` as orde
                INNER JOIN `" . _DB_PREFIX_ . "customer` cust ON (cust.id_customer = orde.id_customer) 
                LEFT JOIN `" . _DB_PREFIX_ . "tnt_recogida_label` tnt_lab on tnt_lab.id_order = orde.id_order
		LEFT JOIN `" . _DB_PREFIX_ . "order_state` os ON (os.`id_order_state` = orde.`current_state`) 
		LEFT JOIN `" . _DB_PREFIX_ . "order_state_lang` osl ON (os.`id_order_state` = osl.`id_order_state` AND osl.`id_lang` = " . (int) $lang . ")
                where orde.current_state in (" . Configuration::get('TNT_ORDER_STATUS_NO_LABEL') . "," . Configuration::get('TNT_ORDER_STATUS_LABELED') . "," . Configuration::get('TNT_ORDER_STATUS_SENDED') . ")
                " . ($reference ? " and orde.reference like '%" . $reference . "%'" : '') . "    
                " . ($connumber ? " and tnt_lab.connumber like '%" . $connumber . "%'" : '') . "    
                " . ($client ? " and (cust.firstname like '%" . $client . "%' or cust.lastname like '%" . $client . "%')" : '') . "    
                " . ($status ? " and orde.current_state = '" . $status . "'" : '') . "    
                " . ($manifested ? " and tnt_lab.manifested is not NULL" : '') . "    
                " . ($booked ? " and tnt_lab.booked like '%" . $booked . "%'" : '') . "
                " . ($manifest_date_ini && $manifest_date_end ? " and tnt_lab.manifested between '" . $manifest_date_ini . "' and '" . $manifest_date_end . "'" : "and (tnt_lab.manifested > '" . date('Y-m-d', strtotime(date('Y-m-d') . ' - 1 day')) . "' or tnt_lab.manifested is null)") . "
                    " . ($order_by ? "order by " . $order_by : "order by orde.current_state asc,orde.id_order desc    ") . "
                ;
		";

        $result = Db::getInstance(_PS_USE_SQL_SLAVE_)->ExecuteS($query);


        if (!$result) {
            return false;
        }
        return $result;
    }

    public static function getOrderStates($id_lang) {


        $result = Db::getInstance(_PS_USE_SQL_SLAVE_)->executeS('
                        SELECT *
                        FROM `' . _DB_PREFIX_ . 'order_state` os
                        LEFT JOIN `' . _DB_PREFIX_ . 'order_state_lang` osl ON (os.`id_order_state` = osl.`id_order_state` AND osl.`id_lang` = ' . (int) $id_lang . ')
                        WHERE deleted = 0
                        and os.id_order_state in (' . Configuration::get('TNT_ORDER_STATUS_NO_LABEL') . ',' . Configuration::get('TNT_ORDER_STATUS_LABELED') . ',' . Configuration::get('TNT_ORDER_STATUS_SENDED')  . ')
                        ORDER BY `name` ASC');
        if (!$result) {
            return false;
        }
        return $result;
    }

    public static function setShippingNumber($order_id,$shipping_number){
        $id_order_carrier = Db::getInstance()->getValue('
                        SELECT `id_order_carrier`
                        FROM `' . _DB_PREFIX_ . 'order_carrier`
                        WHERE `id_order` = ' . (int) $order_id);
        if ($id_order_carrier) {
            $order_carrier = new OrderCarrier($id_order_carrier);
            $order_carrier->tracking_number = $shipping_number;
            $order_carrier->id_carrier = Configuration::get('tnt_carrier');
            $order_carrier->update();
        }
        return true;
    }
}
