<?php

/*
 * 2007-2014 PrestaShop
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Open Software License (OSL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/osl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to http://www.prestashop.com for more information.
 *
 *  @author PrestaShop SA <contact@prestashop.com>
 *  @copyright  2007-2014 PrestaShop SA
 *  @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
 *  International Registered Trademark & Property of PrestaShop SA
 */
include_once dirname(__FILE__) . '/../../classes/tnt/TntAccount.php';
include_once dirname(__FILE__) . '/../../classes/tnt/TntAccountAddress.php';

class AdminTntAccountAddressController extends AdminController {

    /** @var array countries list */
    protected $countries_array = array();
    protected $accounts_array = array();

    public function __construct() {
        $this->bootstrap = true;
        $this->table = 'tnt_account_address';
        $this->className = 'TntAccountAddress';
        $this->lang = false;
        $this->addressType = 'customer';
        $this->explicitSelect = true;
        $this->context = Context::getContext();

        $this->addRowAction('edit');
        $this->addRowAction('delete');

        if (!Tools::getValue('realedit'))
            $this->deleted = true;

        $countries = Country::getCountries($this->context->language->id);

        foreach ($countries as $country)
            $this->countries_array[$country['id_country']] = $country['name'];

        $accounts_array = array();
        $accounts = TntAccount::getTntAccount();

        foreach ($accounts as $key => $account) {
            $accounts_array[$key] = $account['name'];
        }

        $this->fields_list = array(
            'id_tnt_account_address' => array('title' => $this->l('ID'),
                'align' => 'center',
                'class' => 'fixed-width-xs'),
            'id_tnt_account' => array(
                'title' => $this->l('Cuenta'),
                'orderby' => false,
                'type' => 'select',
                'list' => $accounts_array,
                'filter_key' => 'a!id_tnt_account',
                'callback' => 'displayAccount',
                'callback_object' => $this
            ),
            'address_1' => array('title' => $this->l('Dirección 1')),
            
            'postcode' => array('title' => $this->l('Código postal'),
                'align' => 'right'),
            'city' => array('title' => $this->l('Ciudad')),
            'country' => array('title' => $this->l('País'),
                'type' => 'select',
                'list' => $this->countries_array,
                'filter_key' => 'cl!id_country'));

        parent::__construct();

        $this->_select = 'cl.`name` as country';
        $this->_join = '
			LEFT JOIN `' . _DB_PREFIX_ . 'country_lang` cl ON (cl.`id_country` = a.`id_country` AND cl.`id_lang` = ' . (int) $this->context->language->id . ')
		';
    }

    public function initPageHeaderToolbar() {
        if (empty($this->display))
            $this->page_header_toolbar_btn['new_address'] = array(
                'href' => self::$currentIndex . '&addtnt_account_address&token=' . $this->token,
                'desc' => $this->l('Agregar nueva dirección', null, null, false),
                'icon' => 'process-icon-new'
            );

        parent::initPageHeaderToolbar();
    }

    public function displayAccount($value, $tr) {
        return $this->fields_list['id_tnt_account']['list'][$value];
    }

    public function renderForm() {
        $this->fields_form = array(
            'legend' => array(
                'title' => $this->l('Dirección'),
                'icon' => 'icon-envelope-alt'
            ),
            'input' => array(
                array(
                    'type' => 'select',
                    'label' => $this->l('Cuenta'),
                    'name' => 'id_tnt_account',
                    'required' => false,
                    'col' => '4',
                    'options' => array(
                        'query' => TntAccount::getTntAccount(),
                        'id' => 'id_tnt_account',
                        'name' => 'name'
                    )
                ),
                array(
                    'type' => 'text',
                    'label' => $this->l('Dirección 1'),
                    'name' => 'address_1',
                    'required' => true,
                    'col' => '2'
                ),
                array(
                    'type' => 'text',
                    'label' => $this->l('Dirección 2'),
                    'name' => 'address_2',
                    'required' => false,
                    'col' => '2'
                ),
                array(
                    'type' => 'text',
                    'label' => $this->l('Dirección 3'),
                    'name' => 'address_3',
                    'required' => false,
                    'col' => '2'
                ),
                array(
                    'type' => 'text',
                    'label' => $this->l('Código postal'),
                    'name' => 'postcode',
                    'col' => '2',
                    'required' => true,
                ),
                array(
                    'type' => 'text',
                    'label' => $this->l('Ciudad'),
                    'name' => 'city',
                    'col' => '2',
                    'required' => true,
                ),
                array(
                    'type' => 'select',
                    'label' => $this->l('País'),
                    'name' => 'id_country',
                    'required' => true,
                    'col' => '4',
                    'default_value' => (int) $this->context->country->id,
                    'options' => array(
                        'query' => Country::getCountries($this->context->language->id),
                        'id' => 'id_country',
                        'name' => 'name'
                    )
                ),
                array(
                    'type' => 'select',
                    'label' => $this->l('Provincia'),
                    'name' => 'id_state',
                    'required' => false,
                    'col' => '4',
                    'options' => array(
                        'query' => array(),
                        'id' => 'id_state',
                        'name' => 'name'
                    )
                ),
            ),
            'submit' => array(
                'title' => $this->l('Guardar'),
            )
        );

        return parent::renderForm();
    }

    public function processSave() {
        /*
         * Aquí añadir los WS
         * 
         */
        if (Tools::getValue('submitFormAjax'))
            $this->redirect_after = false;

        /* If the selected country does not contain states */
        $id_state = (int) Tools::getValue('id_state');
        $id_country = (int) Tools::getValue('id_country');
        $country = new Country((int) $id_country);
        if ($country && !(int) $country->contains_states && $id_state)
            $this->errors[] = Tools::displayError('You have selected a state for a country that does not contain states.');

        /* If the selected country contains states, then a state have to be selected */
        if ((int) $country->contains_states && !$id_state)
            $this->errors[] = Tools::displayError('An address located in a country containing states must have a state selected.');

        $postcode = Tools::getValue('postcode');
        /* Check zip code format */
        if ($country->zip_code_format && !$country->checkZipCode($postcode))
            $this->errors[] = Tools::displayError('Your Zip/postal code is incorrect.') . '<br />' . Tools::displayError('It must be entered as follows:') . ' ' . str_replace('C', $country->iso_code, str_replace('N', '0', str_replace('L', 'A', $country->zip_code_format)));
        elseif (empty($postcode) && $country->need_zip_code)
            $this->errors[] = Tools::displayError('A Zip/postal code is required.');
        elseif ($postcode && !Validate::isPostCode($postcode))
            $this->errors[] = Tools::displayError('The Zip/postal code is invalid.');

        if (empty($this->errors))
            return parent::processSave();
        else
        // if we have errors, we stay on the form instead of going back to the list
            $this->display = 'edit';
    }

    public function processAdd() {
        if (Tools::getValue('submitFormAjax'))
            $this->redirect_after = false;

        return parent::processAdd();
    }

    /**
     * Get Address formats used by the country where the address id retrieved from POST/GET is.
     *
     * @return array address formats
     */
    protected function processAddressFormat() {
        $tmp_addr = new TntAccountAddress((int) Tools::getValue('id_tnt_account_address'));

        $selected_country = ($tmp_addr && $tmp_addr->id_country) ? $tmp_addr->id_country : (int) Configuration::get('PS_COUNTRY_DEFAULT');

        $inv_adr_fields = AddressFormat::getOrderedAddressFields($selected_country, false, true);
        $dlv_adr_fields = AddressFormat::getOrderedAddressFields($selected_country, false, true);

        $inv_all_fields = array();
        $dlv_all_fields = array();

        $out = array();

        foreach (array('inv', 'dlv') as $adr_type) {
            foreach (${$adr_type . '_adr_fields'} as $fields_line)
                foreach (explode(' ', $fields_line) as $field_item)
                    ${$adr_type . '_all_fields'}[] = trim($field_item);

            $out[$adr_type . '_adr_fields'] = ${$adr_type . '_adr_fields'};
            $out[$adr_type . '_all_fields'] = ${$adr_type . '_all_fields'};
        }

        return $out;
    }

    /**
     * Method called when an ajax request is made
     * @see AdminController::postProcess()
     */
    public function ajaxProcess() {
        if (Tools::isSubmit('email')) {
            $email = pSQL(Tools::getValue('email'));
            $customer = Customer::searchByName($email);
            if (!empty($customer)) {
                $customer = $customer['0'];
                echo Tools::jsonEncode(array('infos' => pSQL($customer['firstname']) . '_' . pSQL($customer['lastname']) . '_' . pSQL($customer['company'])));
            }
        }
        die;
    }

    /**
     * Object Delete
     */
    public function processDelete() {
        if (Validate::isLoadedObject($object = $this->loadObject())) {
            if (!$object->getAddressIsUsed($object->id)) {
                $this->deleted = false;
                return parent::processDelete();
            } else {
                $this->errors[] = Tools::displayError('Account used.');
                return false;
            }
        }
    }

    /**
     * Delete multiple items
     *
     * @return boolean true if succcess
     */
    protected function processBulkDelete() {
        if (is_array($this->boxes) && !empty($this->boxes)) {
            $deleted = false;
            foreach ($this->boxes as $id) {
                $to_delete = new TntAccountAddress((int) $id);
                if ($to_delete->isUsed()) {
                    $deleted = true;
                    break;
                }
            }
            $this->deleted = $deleted;
        }

        return parent::processBulkDelete();
    }

}
