<?php

/*
 * 2007-2014 PrestaShop
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Open Software License (OSL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/osl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to http://www.prestashop.com for more information.
 *
 *  @author PrestaShop SA <contact@prestashop.com>
 *  @copyright  2007-2014 PrestaShop SA
 *  @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
 *  International Registered Trademark & Property of PrestaShop SA
 */

include_once dirname(__FILE__) . '/../../classes/tnt/TntAccount.php';
include_once dirname(__FILE__) . '/../../classes/tnt/TntService.php';

class AdminTntAccountController extends AdminController {

    public function __construct() {
        $this->bootstrap = true;
        $this->table = 'tnt_account';
        $this->className = 'TntAccount';
        $this->lang = false;

        /*
          $connect = new TntConnect();
          ($connect->setCompany('TNTBPDt')->setAccount('734677')->setPassword('tnt12345')->generateID());
          //echo "\n\n\n";
          //echo $xml = ($connect->getResult());
          echo $connect->parse($connect->getManifest());
          die;
         * 
         */
        $this->context = Context::getContext();

        $this->fields_list = array(
            'id_tnt_account' => array(
                'title' => $this->l('ID'),
                'align' => 'center',
                'col' => '2'
            ),
            'name' => array(
                'title' => $this->l('Descripción de la cuenta')
            ),
            'loginuser' => array(
                'title' => $this->l('Login')
            ),
            'account' => array(
                'title' => $this->l('Cuenta')
            ),
            'principal' => array(
                'title' => $this->l('Principal'),
                'active' => 'principal',
                'type' => 'bool',
                'orderby' => false,
                'align' => 'center',
                'class' => 'fixed-width-sm'
            ),
            'active' => array(
                'title' => $this->l('Activado'),
                'active' => 'status',
                'type' => 'bool',
                'orderby' => false,
                'align' => 'center',
                'class' => 'fixed-width-sm'
            )
        );

        

        parent::__construct();
    }

    public function initPageHeaderToolbar() {
        if (empty($this->display))
            $this->page_header_toolbar_btn['new_tnt_account'] = array(
                'href' => self::$currentIndex . '&addtnt_account&token=' . $this->token,
                'desc' => $this->l('Crear nueva cuenta de TNT', null, null, false),
                'icon' => 'process-icon-new'
            );

        parent::initPageHeaderToolbar();
    }

    public function renderList() {
        $this->addRowAction('edit');
        $this->addRowAction('delete');

        return parent::renderList();
    }

    public function renderForm() {
        $this->fields_form = array(
            'legend' => array(
                'title' => $this->l('Cuenta Tnt'),
                'icon' => 'icon-money'
            ),
            'input' => array(
                array(
                    'type' => 'text',
                    'label' => $this->l('Descripción de la cuenta'),
                    'name' => 'name',
                    'required' => true,
                    'col' => '2'
                ),
                array(
                    'type' => 'text',
                    'label' => $this->l('Usuario'),
                    'name' => 'loginuser',
                    'required' => true,
                    'col' => '2'
                ),
                array(
                    'type' => 'password',
                    'label' => $this->l('Contraseña'),
                    'name' => 'password',
                    'required' => true,
                    'col' => '2'
                ),
                array(
                    'type' => 'text',
                    'label' => $this->l('Cuenta'),
                    'name' => 'account',
                    'required' => true,
                    'col' => '2'
                ),
                array(
                    'type' => 'radio',
                    'label' => $this->l('Notificación por Email'),
                    'name' => 'envio_email_cliente',
                    'required' => true,
                    'class' => 't',
                    'is_bool' => true,
                    'values' => array(
                        array(
                            'id' => 'active_on',
                            'value' => 1,
                            'label' => $this->l('Habilitado')
                        ),
                        array(
                            'id' => 'active_off',
                            'value' => 0,
                            'label' => $this->l('Deshabilitado')
                        )
                    ),
                    'desc' => $this->l('Si activa esta opción se le mandara un email al destinatario con el número de albarán y con una URL de seguimiento del envio.'),
                ),
                array(
                    'type' => 'text',
                    'label' => $this->l('Ancho'),
                    'name' => 'width',
                    'required' => true,
                    'col' => '2',
                    'suffix' => 'cm'
                ),
                array(
                    'type' => 'text',
                    'label' => $this->l('Alto'),
                    'name' => 'height',
                    'required' => true,
                    'col' => '2',
                    'suffix' => 'cm'
                ),
                array(
                    'type' => 'text',
                    'label' => $this->l('Largo'),
                    'name' => 'depth',
                    'required' => true,
                    'col' => '2',
                    'suffix' => 'cm'
                ),
                array(
                    'type' => 'text',
                    'label' => $this->l('Peso'),
                    'name' => 'weight',
                    'required' => true,
                    'col' => '2',
                    'suffix' => 'kg'
                ),
                array(
                    'type' => 'text',
                    'label' => $this->l('Hora de recogida desde'),
                    'name' => 'prefered_time_in',
                    'required' => true,
                    'col' => '2',
                    'suffix' => 'formato hh:mm'
                ),
                array(
                    'type' => 'text',
                    'label' => $this->l('Hasta'),
                    'name' => 'prefered_time_out',
                    'required' => true,
                    'col' => '2',
                    'suffix' => 'formato hh:mm'
                ),
                array(
                    'type' => 'text',
                    'label' => $this->l('Nombre de la empresa'),
                    'name' => 'company_name',
                    'required' => true,
                    'col' => '2'
                ),
                array(
                    'type' => 'text',
                    'label' => $this->l('Dirección de la empresa'),
                    'name' => 'company_address_1',
                    'required' => true,
                    'col' => '2'
                ),
                array(
                    'type' => 'text',
                    'label' => $this->l('Dirección de la empresa 2'),
                    'name' => 'company_address_2',
                    'required' => false,
                    'col' => '2'
                ),
                array(
                    'type' => 'text',
                    'label' => $this->l('Dirección de la empresa 3'),
                    'name' => 'company_address_3',
                    'required' => false,
                    'col' => '2'
                ),
                array(
                    'type' => 'text',
                    'label' => $this->l('Ciudad'),
                    'name' => 'company_city',
                    'required' => true,
                    'col' => '2'
                ),
                array(
                    'type' => 'text',
                    'label' => $this->l('Código postal'),
                    'name' => 'company_postcode',
                    'required' => true,
                    'col' => '2'
                ),
                array(
                    'type' => 'select',
                    'label' => $this->l('País'),
                    'name' => 'id_country',
                    'required' => true,
                    'col' => '4',
                    'default_value' => (int) $this->context->country->id,
                    'options' => array(
                        'query' => Country::getCountries($this->context->language->id),
                        'id' => 'id_country',
                        'name' => 'name'
                    )
                ),
                array(
                    'type' => 'select',
                    'label' => $this->l('Provincia'),
                    'name' => 'id_state',
                    'required' => false,
                    'col' => '4',
                    'options' => array(
                        'query' => array(1 => 1, 2 => 2),
                        'id' => 'id_state',
                        'name' => 'name'
                    )
                ),
                array(
                    'type' => 'text',
                    'label' => $this->l('Vat'),
                    'name' => 'company_vat',
                    'required' => false,
                    'col' => '2'
                ),
                array(
                    'type' => 'text',
                    'label' => $this->l('Persona de contacto'),
                    'name' => 'company_contact_name',
                    'required' => true,
                    'col' => '2'
                ),
                array(
                    'type' => 'text',
                    'label' => $this->l('Prefijo'),
                    'name' => 'company_contact_dial_code',
                    'required' => true,
                    'col' => '2'
                ),
                array(
                    'type' => 'text',
                    'label' => $this->l('Teléfono de contacto'),
                    'name' => 'company_contact_telephone',
                    'required' => true,
                    'col' => '2'
                ),
                array(
                    'type' => 'text',
                    'label' => $this->l('Email persona de contacto'),
                    'name' => 'company_contact_email',
                    'required' => true,
                    'col' => '2'
                ),
                array(
                    'type' => 'select',
                    'label' => $this->l('Servicio'),
                    'name' => 'id_tnt_service[]',
                    'required' => true,
                    'multiple' => true,
                    'options' => array(
                        'query' => TntService::getTntServiceLabels(),
                        'id' => 'id_tnt_service',
                        'name' => 'name'
                    ),
                    'class' => 'fixed-width-xxl',
                    'desc' => $this->l('Use CTRL+CLICK para seleccionar varios servicios.'),
                ),
                array(
                    'type' => 'select',
                    'label' => $this->l('Servicio predefinido'),
                    'name' => 'id_tnt_service_default',
                    'required' => true,
                    'options' => array(
                        'query' => TntService::getTntServiceLabels(),
                        'id' => 'id_tnt_service',
                        'name' => 'name'
                    ),
                    'class' => 'fixed-width-xxl',
                    'desc' => $this->l('Servicio por defecto.'),
                ),
                array(
                    'type' => 'radio',
                    'label' => $this->l('Habilitado'),
                    'name' => 'active',
                    'required' => true,
                    'class' => 't',
                    'is_bool' => true,
                    'values' => array(
                        array(
                            'id' => 'active_on',
                            'value' => 1,
                            'label' => $this->l('Habilitado')
                        ),
                        array(
                            'id' => 'active_off',
                            'value' => 0,
                            'label' => $this->l('Deshabilitado')
                        )
                    )
                ),
                array(
                    'type' => 'radio',
                    'label' => $this->l('Principal'),
                    'name' => 'principal',
                    'required' => false,
                    'class' => 't',
                    'is_bool' => true,
                    'values' => array(
                        array(
                            'id' => 'active_on',
                            'value' => 1,
                            'label' => $this->l('Habilitado')
                        ),
                        array(
                            'id' => 'active_off',
                            'value' => 0,
                            'label' => $this->l('Deshabilitado')
                        )
                    )
                )
            ),
            'submit' => array(
                'title' => $this->l('Guardar'),
                'stay' => true
            )
        );
        


        $this->fields_value['id_tnt_service[]'] = (array) explode(",",$this->object->id_tnt_service);
        

        if (!($obj = $this->loadObject(true)))
            return;

        /*
         * Nota: A partir de aquí añadir la parte XML
         */

        if (!isset($obj->id)) {
            // Create
            $this->no_back = false;
            $content = parent::renderForm();
        } else {
            // Edit
            $this->no_back = true;
            $this->page_header_toolbar_btn['new'] = array(
                'href' => '#',
                'desc' => $this->l('Crear nueva cuenta')
            );
            $content = parent::renderForm();
        }

        return $content;
    }

    public function initProcess() {
        if (Tools::isSubmit('principaltnt_account')) {
            if ($this->tabAccess['edit'] === '1')
                $this->action = 'cambiaPrincipal';
            else
                $this->errors[] = Tools::displayError('You do not have permission to delete this.');
        }
        else if (Tools::isSubmit('submitBulkdeletetax_rule')) {
            if ($this->tabAccess['delete'] === '1')
                $this->action = 'bulk_delete_tax_rules';
            else
                $this->errors[] = Tools::displayError('You do not have permission to delete this.');
        }
        else if (Tools::getValue('action') == 'create_rule') {
            if ($this->tabAccess['add'] === '1')
                $this->action = 'create_rule';
            else
                $this->errors[] = Tools::displayError('You do not have permission to add this.');
        }
        else {
            parent::initProcess();
        }
    }

    public function processUpdate() {

        parent::validateRules();
        if (!empty($this->errors)) {
            return false;
        }

        $connect = new TntConnect();
        
        if ($connect
                        ->setCompanyName(Tools::getValue('company_name'))
                        ->setCompanyAddress1(Tools::getValue('company_address_1'))
                        ->setCompanyAddress2(Tools::getValue('company_address_2'))
                        ->setCompanyAddress3(Tools::getValue('company_address_3'))
                        ->setCompanyCity(Tools::getValue('company_city'))
                        ->setCompanyProvince(State::getNameById(Tools::getValue('id_state')))
                        ->setCompanyPostcode(Tools::getValue('company_postcode'))
                        ->setCompanyCountry(Country::getIsoById(Tools::getValue('id_country')))
                        ->setCompanyVat(Tools::getValue('company_vat'))
                        ->setCompanyContactName(Tools::getValue('company_contact_name'))
                        ->setCompanyContactDialCode(Tools::getValue('company_contact_dial_code'))
                        ->setCompanyContactTelephone(Tools::getValue('company_contact_telephone'))
                        ->setCompanyContactEmail(Tools::getValue('company_contact_email'))
                        ->setSenderStreetAddres1(Tools::getValue('company_address_1'))
                        ->setSenderStreetAddres2(Tools::getValue('company_address_2'))
                        ->setSenderStreetAddres3(Tools::getValue('company_address_3'))
                        ->setSenderCity(Tools::getValue('company_city'))
                        ->setSenderProvince(Tools::getValue('company_province'))
                        ->setSenderPostCode(Tools::getValue('company_postcode'))
                        ->setCompany(Tools::getValue('loginuser'))
                        ->setAccount(Tools::getValue('account'))
                        ->setPassword(Tools::getValue('password'))
                        ->generateID()
        ) {
            return parent::processUpdate();
        }

        $this->errors[] = Tools::displayError('Conection error.');
        return false;
    }

    public function processAdd() {

        parent::validateRules();
        if (!empty($this->errors)) {
            return false;
        }

        $connect = new TntConnect();

        if ($connect
                        ->setCompanyName(Tools::getValue('company_name'))
                        ->setCompanyAddress1(Tools::getValue('company_address_1'))
                        ->setCompanyAddress2(Tools::getValue('company_address_2'))
                        ->setCompanyAddress3(Tools::getValue('company_address_3'))
                        ->setCompanyCity(Tools::getValue('company_city'))
                        ->setCompanyProvince(State::getNameById(Tools::getValue('id_state')))
                        ->setCompanyPostcode(Tools::getValue('company_postcode'))
                        ->setCompanyCountry(Country::getIsoById(Tools::getValue('id_country')))
                        ->setCompanyVat(Tools::getValue('company_vat'))
                        ->setCompanyContactName(Tools::getValue('company_contact_name'))
                        ->setCompanyContactDialCode(Tools::getValue('company_contact_dial_code'))
                        ->setCompanyContactTelephone(Tools::getValue('company_contact_telephone'))
                        ->setCompanyContactEmail(Tools::getValue('company_contact_email'))
                        ->setSenderStreetAddres1(Tools::getValue('company_address_1'))
                        ->setSenderCity(Tools::getValue('company_city'))
                        ->setSenderProvince(Tools::getValue('company_province'))
                        ->setSenderPostCode(Tools::getValue('company_postcode'))
                        ->setCompany(Tools::getValue('loginuser'))
                        ->setAccount(Tools::getValue('account'))
                        ->setPassword(Tools::getValue('password'))
                        ->getResult()
        ) {
            return parent::processAdd();
        }

        $this->errors[] = Tools::displayError('Error de conexión.');
        return false;
    }

    public function processCambiaPrincipal() {
        
        if (parent::processUpdate()) {
            return TntAccount::processCambiaPrincipal(Tools::getValue('id_tnt_account'));
        }else{
            echo "nada";die;
        }
        //return parent::processUpdate(Tools::getValue('id_tnt_account'));
        //Tools::redirectAdmin(self::$currentIndex.'&token='.$this->token);
    }

}
